Machine-readable error codes returned by the runtime bridge.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- instanceNotFound → const String
- internalError → const String
- invalidParameter → const String
- invalidRequest → const String
- nodeNotFound → const String
- unsupportedMethod → const String