SvgDebugNodeSummary class

Lazy tree row. Attributes are intentionally omitted.

Constructors

SvgDebugNodeSummary({required String nodeId, required String tagName, required String? svgId, required List<String> classes, required int childCount, required bool animated})
const
SvgDebugNodeSummary.fromJson(Map<String, Object?> json)
factory

Properties

animated bool
final
childCount int
final
classes List<String>
final
hashCode int
The hash code for this object.
no setterinherited
nodeId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
svgId String?
final
tagName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited