ColorMapper class abstract

A class that transforms one color into another during SVG parsing.

Implementations must be immutable so they are suitable for use as part of an SVG cache key.

Annotations

Constructors

ColorMapper()
Allows const constructors on subclasses.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
substitute(String? id, String elementName, String attributeName, Color color) Color
Returns a new color to use in place of color.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited