Protocol method names and common response keys.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- clearHighlight → const String
- getInstance → const String
- getInstances → const String
- getNode → const String
- getProtocolVersion → const String
- getStats → const String
- getTree → const String
- highlightNode → const String
-
methods
→ const List<
String> - namespace → const String
- pause → const String
- play → const String
- seek → const String
- setPlaybackRate → const String
- version → const int