SvgDebugInstanceSummary class
Lightweight row shown in the live-instance list.
Constructors
- SvgDebugInstanceSummary({required String instanceId, required String? sourceType, required String? sourceLabel, required double? width, required double? height, required bool animated, required bool playing, required int? currentTimeMs, required int? durationMs, required double playbackRate, required int nodeCount, required int animationCount, required bool hasJavaScript, required bool hasFilters, required bool hasMasks, required bool hasClipPaths})
-
const
-
SvgDebugInstanceSummary.fromJson(Map<
String, Object?> json) -
factory
Properties
- animated → bool
-
final
- animationCount → int
-
final
- currentTimeMs → int?
-
final
- durationMs → int?
-
final
- hasClipPaths → bool
-
final
- hasFilters → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasJavaScript → bool
-
final
- hasMasks → bool
-
final
- height → double?
-
final
- instanceId → String
-
final
- nodeCount → int
-
final
- playbackRate → double
-
final
- playing → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceLabel → String?
-
final
- sourceType → String?
-
final
- width → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited