SvgDebugStats class
Constructors
- SvgDebugStats({required int domNodes, required int animationCount, required int activeAnimationCount, required int filterPrimitiveCount, required int maskCount, required int gradientCount, required int clipPathCount, required bool javaScriptEnabled, required int? currentTimeMs, required int? durationMs})
-
const
-
SvgDebugStats.fromJson(Map<
String, Object?> json) -
factory
Properties
- activeAnimationCount → int
-
final
- animationCount → int
-
final
- clipPathCount → int
-
final
- currentTimeMs → int?
-
final
- domNodes → int
-
final
- durationMs → int?
-
final
- filterPrimitiveCount → int
-
final
- gradientCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- javaScriptEnabled → bool
-
final
- maskCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited